function registerCylinFTAxes(obj, ax)
    initAxes(ax);

    click_callback = @(src, evt)(obj.cylinFTClickedCallback(src, evt));
    ndShowFTSpec = comg.Node.output("Show Fourier Spectrum", ...
            @(spec2show)(showFTSpec(ax, click_callback, spec2show)), ...
            obj.ndTylLogSpec ...
        ).activate();

    comg.Node.output("Show Reciprocal Vectors", ...
            @(stat_setva, stat_setvb, rpva, rpvb)(showRecVecs(ax, stat_setva, stat_setvb, rpva, rpvb)), ...
            obj.ndStatTFFTVa, obj.ndStatTFFTVb, obj.ndSpecVa, obj.ndSpecVb  ...
        ).activate().after(ndShowFTSpec);

    comg.Node.output("Show Lattice Grid", ...
            @(stat_setvs, stat_vsvalid, rpva, rpvb)(showLattGrid(ax, stat_setvs, stat_vsvalid, rpva, rpvb)), ...
            obj.ndStatTFFTVs, obj.ndStatRpvValid, obj.ndSpecVa, obj.ndSpecVb  ...
        ).activate().after(ndShowFTSpec);
end

function initAxes(ax)
    colormap(ax, 'gray');
    title(ax, "Spectrum");
    hold(ax, "on");
end

function showFTSpec(spec_ax, click_callback, spec2show)
    persistent handle_spec;

    delete(handle_spec);
    fang = cencoord(size(spec2show, 2), 1/2/pi);
    flen = cencoord(size(spec2show, 1), 1/size(spec2show, 1));

    handle_spec = imagesc(spec_ax,...
        fang, flen, spec2show,...
        "ButtonDownFcn", click_callback);
    xlim(spec_ax, [fang(1)-5/2/pi,fang(end)+5/2/pi]);
    ylim(spec_ax, [-0.55, 0.55]);
end

function showRecVecs(spec_ax, stat_setva, stat_setvb, rpva, rpvb)
    persistent handle_veca;
    persistent handle_vecb;
    color = [.4, .8, .4];

    delete(handle_veca);
    delete(handle_vecb);
    if ~isempty(rpva) && ~stat_setva
        handle_veca = plot(spec_ax, ...
            [0, rpva(1)/2/pi], [0, rpva(2)], ...
            'Color', color, ...
            'LineWidth', 2);
    end
    if ~isempty(rpvb) && ~stat_setvb
        handle_vecb = plot(spec_ax, ...
            [0, rpvb(1)/2/pi], [0, rpvb(2)], ...
            'Color', color, ...
            'LineWidth', 2);
    end
end

function showLattGrid(spec_ax, stat_ftsel, stat_vsvalid, rpva, rpvb)
    persistent handle_lattlines;
    color = [.4, .4, .8];

    for ii = 1:numel(handle_lattlines)
        delete(handle_lattlines{ii});
    end
    if ~stat_ftsel && stat_vsvalid
        [stpts, edpts] = helix.latticeLines(rpva./[2*pi,1], rpvb./[2*pi,1], spec_ax.XLim, spec_ax.YLim, [0;0]);
        Nlin = size(stpts, 2);

        handle_lattlines = cell(Nlin, 2);
        for il = 1:Nlin
            handle_lattlines{il} = plot(spec_ax, ...
                [stpts(1,il), edpts(1, il)], [stpts(2,il), edpts(2, il)], ...
                'Color', [color, 0.5], ...
                'LineStyle', '--');
        end
    end
    

end



