function registerFilaSecAxes(obj, ax)
    initAxes(ax);

    click_callback = @(src, evt)(obj.filaSecClickedCallback(src, evt));
    ndShowFilaSec = comg.Node.output("Show Filament Section", ...
            @(extr_fila_rect, secind, avgnum)(showFilaSec(ax, click_callback, extr_fila_rect, secind, avgnum)), ...
            obj.ndExtrFilaRect, obj.ndFilaSecInd, obj.ndFilaSecAvgNum ...
        ).activate();

    comg.Node.output("Show TF Current Point", ...
            @(selptcyl, secind, flag_show)(showCurrPoint(ax, selptcyl, secind, flag_show)), ...
            obj.ndTFCurrPtCyl, obj.ndFilaSecInd, obj.ndStatTFShowCurrPt ...
        ).activate().after(ndShowFilaSec);

    comg.Node.output("Show TF New Filament Points", ...
            @(ptinsec, ptlens, secind, focsecind, flag_foc)(showNewFilaPoint(ax, ptinsec, ptlens, secind, focsecind, flag_foc)), ...
            obj.ndTFNewFilaSmthPtsInSec, obj.ndTFNewFilaSmthPtLens, obj.ndFilaSecInd, obj.ndTFFocPtSecInd, obj.ndStatTFFoc ...
        ).activate().after(ndShowFilaSec);

    comg.Node.output("Show Reference Rings on Filament Section", ...
            @(innrad, outrad)(showRefRing(ax, innrad, outrad)), ...
            obj.ndFilaInnRad, obj.ndFilaOutRad ...
        ).activate().after(ndShowFilaSec);

end

function initAxes(ax)
    xlabel(ax, "x");
    ylabel(ax, "y");
    colormap(ax, 'gray');
    hold(ax, "on");
    axis(ax, "equal");
    title(ax, "Section");
end

function showFilaSec(filasec_ax, click_callback, extr_fila_rect, secind, avgnum)
    persistent handle_filasec;

    delete(handle_filasec);
    sx = cencoord(size(extr_fila_rect, 1));
    avgidx = secind + cencoord(avgnum); 
    avgidx(avgidx < 1) = [];
    avgidx(avgidx > size(extr_fila_rect, 3)) = [];
    %min(size(extr_fila_rect, 3), max(1, secind + cencoord(avgnum)));
    handle_filasec = imagesc(filasec_ax, sx, sx, sum(extr_fila_rect(:,:,avgidx),3),...
        'ButtonDownFcn', click_callback);

end

function showCurrPoint(filasec_ax, selptcyl, secind, flag_show)
    persistent handle_selpt;
    color = [.4, .4, .8, .4];

    delete(handle_selpt);
    if flag_show && ~isempty(selptcyl)
        if abs(1 + selptcyl(3) - secind) <= 1
            handle_selpt = plot(filasec_ax, ...
                selptcyl(2), selptcyl(1), ...
                'Marker', 'x', ...
                'Color', color,...
                'LineWidth', 1, ...
                'MarkerSize', 10,...
                'PickableParts', 'none');
        end
    end
end

function showNewFilaPoint(filasec_ax, ptinsec, ptlens, secind, focsecind, flag_foc)
    persistent handle_newfilapt;
    persistent handle_focpt;
    color = [.6, .7, .4, .4];

    delete(handle_newfilapt);
    delete(handle_focpt);

    id = find(abs(secind-ptlens) <= 1, 1);
    showpt = ptinsec(:,id);
    if ~isempty(id)
        handle_newfilapt = plot(filasec_ax, ...
            showpt(2), showpt(1), ...
            'Marker', 'x', ...
            'Color', color,...
            'LineWidth', 1, ...
            'MarkerSize', 10, ...
            'PickableParts', 'none');
        if flag_foc && (secind == focsecind)
            handle_focpt = plot(filasec_ax, ...
                showpt(2), showpt(1), ...
                'Marker', 'o', ...
                'Color', color,...
                'LineWidth', 1, ...
                'MarkerSize', 10, ...
                'PickableParts', 'none');
        end
    end
end


function showRefRing(filasec_ax, innrad, outrad)
    persistent handle_innring;
    persistent handle_outring;
    color = [.4, .4, .8];

    delete(handle_innring);
    delete(handle_outring);

    theta = 0:0.5:360;
    handle_innring = plot(filasec_ax, ...
        cosd(theta)*innrad, sind(theta)*innrad, ...
        'LineStyle', '--', ...
        'Color', color,...
        'LineWidth', 2, ...
        'PickableParts', 'none');

    handle_outring = plot(filasec_ax, ...
        cosd(theta)*outrad, sind(theta)*outrad, ...
        'LineStyle', '-', ...
        'Color', color,...
        'LineWidth', 2, ...
        'PickableParts', 'none');

end




