function insec_bias = findFilamentCenter(extr_fila_rect, varargin)

    persistent p;
    if isempty(p)
        p = inputParser();
        p.addParameter('movmeanlen', 30);
        p.addParameter('movmeanresults', 30);
        p.addParameter('realpadrate', 2);
        p.addParameter('ftpadrate', 2);
        p.addParameter('biasrad', []);
        p.addParameter('secrad', []);
        p.addParameter('rmvavgbg', true);
    end
    p.parse(varargin{:});

    rpr = p.Results.realpadrate;
    fpr = p.Results.realpadrate;

    if p.Results.rmvavgbg
        extr_fila_rect = extr_fila_rect - mean(extr_fila_rect, [1,2]);
    end

    if ~isempty(p.Results.secrad)
        sec_rad = p.Results.secrad;
        [sx, sy] = cencoord(size(extr_fila_rect, [1,2]));
        sr = sqrt(sx.^2 + sy.^2);
        soft_lim = @(r, rlim)((r<rlim)+(r>=rlim).*(r<rlim*1.5).*(0.5+0.5*cos((r-rlim)/rlim*2*pi)));
        sec_mask = soft_lim(sr, sec_rad);
        extr_fila_rect = extr_fila_rect .* sec_mask;
    end

    if ~isempty(p.Results.movmeanlen) && (p.Results.movmeanlen > 1)
        mvavg = movmean(extr_fila_rect, p.Results.movmeanlen, 3);
    else
        mvavg = extr_fila_rect;
    end

    ft_self_corr = cenrsz(real(cifft2(cfft2(cenrsz(mvavg,[rpr,rpr,1].*size(mvavg))).^2)), size(mvavg));
    ft_pad = @(img, fpr)(real(cifft2(cenrsz(cfft2(img),[fpr,fpr,1].*size(img)))));
    ft_self_corr = ft_pad(ft_self_corr, fpr);

    if ~isempty(p.Results.biasrad)
        bias_rad = p.Results.biasrad * fpr * 2;
        [bx, by] = cencoord(size(extr_fila_rect, [1,2])*fpr);
        bias_mask = (bx.^2 + by.^2) <= bias_rad.^2;
        ft_self_corr = ft_self_corr .* bias_mask;
    end

    
    vs = zeros(1, size(ft_self_corr,3));
    cx = zeros(1, size(ft_self_corr,3));
    cy = zeros(1, size(ft_self_corr,3));
    for isec = 1:size(ft_self_corr,3)
        [vs(isec), peak_id] = max(ft_self_corr(:,:,isec), [], 'all');
        [ix, iy] = ind2sub(size(ft_self_corr), peak_id);
        cx(isec) = (ix - cenpos(size(ft_self_corr, 1)))/fpr/2;
        cy(isec) = (iy - cenpos(size(ft_self_corr, 2)))/fpr/2;
    end

    insec_bias = [cx; cy];

    if ~isempty(p.Results.movmeanresults) && (p.Results.movmeanresults > 1)
        insec_bias = movmean(insec_bias, p.Results.movmeanresults, 2, "omitnan", "Endpoints", 0);
    end

end


