function [avg_vol] = helicalSubtomoAveraging_vol(extr_fila_rect, start_num, rise, twist,...
    seg_len, seg_step, RMF_r, RMF_s, RMF_t, tilt_axis, tilt_dir, tilt_ang_range)

    flag_mw_cor = true;
    flag_symmtrize = true;

    fila_len = size(extr_fila_rect, 3);
    seg_pos = 1:seg_step:(fila_len-seg_len+1);
    seg_cen_pos = cenpos(seg_len);
    Nseg = numel(seg_pos);

    avg_vol_sz = seg_len * [1,1,1];
    avg_vol = zeros(avg_vol_sz);
    if flag_mw_cor
        avg_msk = zeros(avg_vol_sz);
    end

    [vx, vy, vz] = cencoord(avg_vol_sz);
    vcd = [vx(:),vy(:),vz(:)];
    vxb = cencoord(avg_vol_sz(1));
    vyb = cencoord(avg_vol_sz(2));
    vzb = cencoord(avg_vol_sz(3));
    for iseg = 1:Nseg
        subvol = extr_fila_rect(:,:,seg_pos(iseg)-1+(1:seg_len));
        subvol = cenrsz(subvol, avg_vol_sz);

        symm_ord = round(seg_pos(iseg)/rise);
        diff_rot = - symm_ord * twist / 180 * pi;
        diff_shift = seg_pos(iseg) - symm_ord * rise;

        q = quaternion([0,0,diff_rot],'rotvec');
        vcd_tran = q.rotateframe(vcd) - [0,0,diff_shift];
        subvol_tran = interp3(vyb, vxb, vzb, subvol, vcd_tran(:,2), vcd_tran(:,1), vcd_tran(:,3), 'linear',0);
        subvol_tran = reshape(subvol_tran, avg_vol_sz);

        if flag_mw_cor
            sc = seg_pos(iseg) - 1 + seg_cen_pos; % segment center
            mw_msk = generate_helix_mwcoef_q(avg_vol_sz, RMF_r(:,sc), RMF_s(:,sc), RMF_t(:,sc), tilt_ang_range);

            q = quaternion([0,0,diff_rot],'rotvec');
            vcd_tran = q.rotateframe(vcd);
            rot_msk = reshape(interp3(vyb, vxb, vzb, mw_msk, vcd_tran(:,2), vcd_tran(:,1), vcd_tran(:,3), 'linear',0), avg_vol_sz);
            
            subvol_tran = real(cifftn(rot_msk .* cfftn(subvol_tran)));

            avg_msk = avg_msk + rot_msk.^2;
        end

        avg_vol = avg_vol + subvol_tran;
    end
    
    if flag_mw_cor
        avg_vol = real(cifftn(cfftn(avg_vol) ./ (1+abs(avg_msk))));
    else
        avg_vol = avg_vol / Nseg;
    end

    if flag_symmtrize
        symm_ord = ceil(seg_step / rise);
        avg_vol = helix.volHelicalSymmetrize(avg_vol, start_num, rise, twist, symm_ord);
    end

end