function [r,s,t] = calcRMF(points, r0)
% calculate the Rotation Minimizing Frame for a seriers of 3D points.
% POINTS: 3xN, N >= 2

    Npt = size(points, 2);
    x = points;
    t = diff(x,[],2);
    t = t./sqrt(sum(t.^2,1));
    t = [t, t(:,end)];

    r = t*0;
    s = t*0;
    t0 = t(:,1);
    
    if ~exist('r0', 'var') || 0==norm(cross(t0,r0))
        r0 = randn(3,1);
        while dot(t0, r0) < 0.1
            r0 = randn(3,1);
        end
    end

    r0 = r0 - dot(r0, t0) * t0;
    r0 = r0 ./ norm(r0);
    s0 = cross(t0, r0);

    r(:,1) = r0;
    s(:,1) = s0;

    for ipt = 1:(Npt-1)
        v1 = x(:,ipt+1) - x(:,ipt);
        c1 = dot(v1,v1);
        riL = r(:,ipt) - (2/c1)*dot(v1, r(:,ipt))*v1;
        tiL = t(:,ipt) - (2/c1)*dot(v1, t(:,ipt))*v1;

        v2 = t(:,ipt+1) - tiL;
        c2 = dot(v2,v2);
        r(:,ipt+1) = riL - (2/c2)*dot(v2, riL)*v2;
        s(:,ipt+1) = cross(t(:,ipt+1), r(:,ipt+1));
    end

end


% test script:
%   pts = [sin(0:0.1:10); cos((0:0.1:10)*0.33+1.1); atan(0:0.1:10)];
%   [r,s,t] = calcRMF(pts);
%   quiver3(pts(1,:), pts(2,:), pts(3,:), r(1,:), r(2,:), r(3,:));
%   hold on;
%   quiver3(pts(1,:), pts(2,:), pts(3,:), s(1,:), s(2,:), s(3,:));

