function q = quat_mapztov(v)
% return a quaternion whose rotmat of 'point' type will map the z-axis
% vector to direction v.
% v should be [3,N] or vector with length 3.

    if numel(v) == 3
        v = v(:);
    end
    v = normalize(v, 1, 'norm');

    q = quaternion(zeros(size(v'),"like",v), 'rotvec');

    for ii = 1:size(v, 2)
        if abs(v(3, ii)) > 1-1e-7
            if v(3, ii) > 0
                q(ii) = quaternion([0, 0, 0], 'rotvec');
            else
                q(ii) = quaternion([pi, 0, 0], 'rotvec');
            end
        else
            z = [0; 0; 1];
            rot_ax = normalize(cross(z, v(:,ii)), 'norm');
            rot_ang = atan2(norm(cross(z, v(:,ii))), dot(z, v(:,ii)));
            q(ii) = quaternion(rot_ax' * rot_ang, 'rotvec');
        end
    end

end